@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2019 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford Ontario Canada
 **  Copyright (C) 2012      John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012      Dave Heiland
 **
@@ -300,10 +300,9 @@ void IndexEditor::Open()
     QString filename = QFileDialog::getOpenFileName(this,
                        tr("Load Entries From File"),
                        m_LastFolderOpen,
-		       filter_string, 
-		       NULL,
-                       options
-                                                   );
+                       filter_string, 
+                       NULL,
+                       options);
 
     // Load the file and save the last folder opened
     if (!filename.isEmpty()) {
@@ -342,9 +341,8 @@ void IndexEditor::SaveAs()
                        tr("Save Entries to File"),
                        m_LastFolderOpen,
                        filter_string,
-		       &default_filter,
-                       options
-                                                   );
+                       &default_filter,
+                       options);
 
     if (filename.isEmpty()) {
         return;
@@ -443,11 +441,11 @@ void IndexEditor::CreateContextMenuActions()
     m_Reload    = new QAction(tr("Reload") + "...",  this);
     m_SaveAs    = new QAction(tr("Save As") + "...", this);
     m_SelectAll = new QAction(tr("Select All"),      this);
-    m_AddEntry->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_E));
+    m_AddEntry->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_E));
     m_Edit->setShortcut(QKeySequence(Qt::Key_F2));
-    m_Cut->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_X));
-    m_Copy->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_C));
-    m_Paste->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_V));
+    m_Cut->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_X));
+    m_Copy->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_C));
+    m_Paste->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_V));
     m_Delete->setShortcut(QKeySequence::Delete);
     // Has to be added to the dialog itself for the keyboard shortcut to work.
     addAction(m_AddEntry);
