@@ -136,8 +136,7 @@ void StylesInCSSFilesWidget::FilterEditTextChangedSlot(const QString &text)
     for (int row = 0; row < root_item->rowCount(); row++) {
         if (text.isEmpty() || root_item->child(row, 0)->text().toLower().contains(lowercaseText) ||
             root_item->child(row, 1)->text().toLower().contains(lowercaseText) ||
-            root_item->child(row, 2)->text().toLower().contains(lowercaseText) ||
-            root_item->child(row, 3)->text().toLower().contains(lowercaseText)) {
+            root_item->child(row, 2)->text().toLower().contains(lowercaseText)) {
             ui.fileTree->setRowHidden(row, parent_index, false);
 
             if (first_visible_row == -1) {
@@ -201,8 +200,8 @@ void StylesInCSSFilesWidget::Delete()
 
 void StylesInCSSFilesWidget::Save()
 {
-    QString report_info;
-    QString row_text;
+    QStringList report_info;
+    QStringList heading_row;
 
     // Get headings
     for (int col = 0; col < ui.fileTree->header()->count(); col++) {
@@ -211,35 +210,25 @@ void StylesInCSSFilesWidget::Save()
         if (item) {
             text = item->text();
         }
-        if (col == 0) {
-            row_text.append(text);
-        } else {
-            row_text.append("," % text);
-        }
+        heading_row << text;
     }
-
-    report_info.append(row_text % "\n");
+    report_info << Utility::createCSVLine(heading_row);
 
     // Get data from table
     for (int row = 0; row < m_ItemModel->rowCount(); row++) {
-        row_text = "";
-
+        QStringList data_row;
         for (int col = 0; col < ui.fileTree->header()->count(); col++) {
             QStandardItem *item = m_ItemModel->item(row, col);
             QString text = "";
             if (item) {
                 text = item->text();
             }
-            if (col == 0) {
-                row_text.append(text);
-            } else {
-                row_text.append("," % text);
-            }
+            data_row << text;
         }
-
-        report_info.append(row_text % "\n");
+        report_info << Utility::createCSVLine(data_row);
     }
 
+    QString data = report_info.join('\n') + '\n';
     // Save the file
     ReadSettings();
     QString filter_string = "*.csv;;*.txt;;*.*";
@@ -251,18 +240,18 @@ void StylesInCSSFilesWidget::Save()
 #endif
 
     QString destination = QFileDialog::getSaveFileName(this,
-                          tr("Save Report As Comma Separated File"),
-                          save_path,
-                          filter_string,
-                          &default_filter,
-                          options);
+                                                       tr("Save Report As Comma Separated File"),
+                                                       save_path,
+                                                       filter_string,
+                                                       &default_filter,
+                                                       options);
 
     if (destination.isEmpty()) {
         return;
     }
 
     try {
-        Utility::WriteUnicodeTextFile(report_info, destination);
+        Utility::WriteUnicodeTextFile(data, destination);
     } catch (CannotOpenFile&) {
         QMessageBox::warning(this, tr("Sigil"), tr("Cannot save report file."));
     }
@@ -272,7 +261,6 @@ void StylesInCSSFilesWidget::Save()
     WriteSettings();
 }
 
-
 void StylesInCSSFilesWidget::CreateContextMenuActions()
 {
     m_Delete    = new QAction(tr("Delete From Stylesheet") + "...",     this);
