@@ -1,7 +1,7 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2021  Kevin B. Hendricks, Stratford Ontario Canada
-**  Copyright (C) 2019-2021  Doug Massay
+**  Copyright (C) 2015-2022  Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2019-2022  Doug Massay
 **  Copyright (C) 2012       Dave Heiland, John Schember
 **
 **  This file is part of Sigil.
@@ -52,16 +52,14 @@ static const QStringList HEADERTAGS = QStringList() << "h1" << "h2" << "h3" << "
 
 static const QString SETTINGS_GROUP = "previewwindow";
 
-static const QString MATHJAX_CLEANUP = 
-   "<script type=\"text/x-mathjax-config\">"
-   "  MathJax.Hub.Register.StartupHook('End', function () {"
-   "    var mscripts = document.querySelectorAll(\"script[type='math/mml']\");"
-   "    function pruneScripts(item, index) {"
-   "      item.parentNode.removeChild(item);"
-   "    }"
-   "    mscripts.forEach(pruneScripts);"
-   "  });"
-   "</script>";;
+static const QString MATHJAX3_CONFIG =
+"  <script> "
+"    MathJax = { "
+"      loader: { "
+"        load: [ '[mml]/mml3', 'core', 'input/mml', 'output/svg' ] "
+"      } "
+"    }; "
+" </script> ";
 
 
 #define DBG if(0)
@@ -79,7 +77,8 @@ PreviewWindow::PreviewWindow(QWidget *parent)
     m_Filepath(QString()),
     m_titleText(QString()),
     m_updatingPage(false),
-    m_usingMathML(false)
+    m_usingMathML(false),
+    m_cycleCSSLevel(0)
 {
     m_progress->reset();
     m_progress->setMinimum(0);
@@ -120,6 +119,13 @@ PreviewWindow::~PreviewWindow()
     }
 }
 
+void PreviewWindow::setUserCSSURLs(const QStringList& usercssurls)
+{
+    m_usercssurls = usercssurls;
+    m_cycleCSSAction->setEnabled(!m_usercssurls.isEmpty());
+    if (!m_usercssurls.isEmpty()) m_cycleCSSLevel = 1;
+}
+
 void PreviewWindow::SetupOverlayTimer()
 {
     m_OverlayTimer.setSingleShot(true);
@@ -230,22 +236,31 @@ void PreviewWindow::SetupView()
     m_Layout->addWidget(m_Preview);
 
     m_inspectAction = new QAction(QIcon(":/main/inspect.svg"),"", this);
+    m_inspectAction ->setEnabled(true);
     m_inspectAction->setToolTip(tr("Inspect Page"));
 
     m_selectAction  = new QAction(QIcon(":/main/edit-select-all.svg"),"", this);
+    m_selectAction ->setEnabled(true);
     m_selectAction->setToolTip(tr("Select-All"));
 
     m_copyAction    = new QAction(QIcon(":/main/edit-copy.svg"),"", this);
+    m_copyAction ->setEnabled(true);
     m_copyAction->setToolTip(tr("Copy Selection To ClipBoard"));
 
     m_reloadAction  = new QAction(QIcon(":/main/reload-page.svg"),"", this);
+    m_reloadAction ->setEnabled(true);
     m_reloadAction->setToolTip(tr("Update Preview Window"));
 
+    m_cycleCSSAction = new QAction(QIcon(":/main/cycle-css.svg"),"", this);
+    m_cycleCSSAction ->setEnabled(false);
+    m_cycleCSSAction->setToolTip(tr("Cycle Custom CSS Files"));
+    
     QToolBar * tb = new QToolBar();
     tb->addAction(m_inspectAction);
     tb->addAction(m_selectAction);
     tb->addAction(m_copyAction);
     tb->addAction(m_reloadAction);
+    tb->addAction(m_cycleCSSAction);
     tb->addWidget(m_progress);
 
     m_buttons->addWidget(tb);
@@ -259,6 +274,15 @@ void PreviewWindow::SetupView()
     QApplication::restoreOverrideCursor();
 }
 
+
+void PreviewWindow::CycleCustomCSS()
+{
+    if (m_usercssurls.isEmpty()) return;
+    m_cycleCSSLevel++;
+    if (m_cycleCSSLevel > m_usercssurls.size()) m_cycleCSSLevel = 0;
+    ReloadPreview();
+}
+
 // Note every call to Update Page needs to be followed by a call
 // to Zoom() as it is not properly zooming after loading
 // But Zoom() is not done synchronously so after zooming
@@ -300,14 +324,14 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
     }
     m_Preview->page()->setBackgroundColor(Utility::WebViewBackgroundColor(true));
 
-    // If the user has set a default stylesheet inject it
-    // it can override anything above it
-    if (!m_usercssurl.isEmpty()) {
+    // If the user has set a default stylesheet inject it last
+    // so it can override anything above it
+    if (!m_usercssurls.isEmpty() && (m_cycleCSSLevel > 0)) {
         int endheadpos = text.indexOf("</head>");
         if (endheadpos > 1) {
             QString inject_userstyles = 
               "<link rel=\"stylesheet\" type=\"text/css\" "
-              "href=\"" + m_usercssurl + "\" />\n";
+                "href=\"" + m_usercssurls.at(m_cycleCSSLevel - 1) + "\" />\n";
             DBG qDebug() << "Preview injecting stylesheet: " << inject_userstyles;
             text.insert(endheadpos, inject_userstyles);
         }
@@ -318,9 +342,12 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
     if (m_usingMathML) {
         int endheadpos = text.indexOf("</head>");
         if (endheadpos > 1) {
-            QString inject_mathjax = MATHJAX_CLEANUP + 
-              "<script type=\"text/javascript\" async=\"async\" "
-              "src=\"" + m_mathjaxurl + "\"></script>\n";
+            QString inject_mathjax;
+            if (m_mathjaxurl.endsWith("startup.js")) {
+                inject_mathjax = MATHJAX3_CONFIG + "<script type=\"text/javascript\" async=\"async\" id=\"MathJax-script\" src=\"" + m_mathjaxurl + "\"></script>\n";
+            } else {
+                inject_mathjax = "<script type=\"text/javascript\" async=\"async\" id=\"MathJax-script\" src=\"" + m_mathjaxurl + "\"></script>\n";
+            }
             text.insert(endheadpos, inject_mathjax);
         }
     }
@@ -447,10 +474,6 @@ QList<ElementIndex> PreviewWindow::GetCaretLocation()
     DBG qDebug() << "PreviewWindow in GetCaretLocation";
     QList<ElementIndex> hierarchy = m_Preview->GetCaretLocation();
     for (int i = 0; i < hierarchy.length(); i++) {
-        if (m_usingMathML && (hierarchy[i].name == "body")) {
-            // compensate for MathJax added two divs injected as first children of body
-            hierarchy[i].index = hierarchy[i].index - 2;
-        }
         DBG qDebug() << "name: " << hierarchy[i].name << " index: " << hierarchy[i].index;
     }
     return hierarchy;
@@ -462,10 +485,6 @@ void PreviewWindow::SetCaretLocation(const QList<ElementIndex> &loc)
     DBG qDebug() << "PreviewWindow in SetCaretLocation";
     QList<ElementIndex> hierarchy;
     foreach(ElementIndex ei, loc) {
-        if (m_usingMathML && (ei.name == "body")) {
-            // compensate for MathJax added two divs injected as first children of body
-            ei.index = ei.index + 2;
-        }
         hierarchy << ei;
         DBG qDebug() << "name: " << ei.name << " index: " << ei.index;
     }
@@ -645,6 +664,7 @@ void PreviewWindow::ConnectSignalsToSlots()
     connect(m_selectAction,  SIGNAL(triggered()),           this, SLOT(SelectAllPreview()));
     connect(m_copyAction,    SIGNAL(triggered()),           this, SLOT(CopyPreview()));
     connect(m_reloadAction,  SIGNAL(triggered()),           this, SLOT(ReloadPreview()));
+    connect(m_cycleCSSAction, SIGNAL(triggered()),          this, SLOT(CycleCustomCSS())); 
     connect(m_Inspector,     SIGNAL(finished(int)),         this, SLOT(InspectorClosed(int)));
     connect(this,     SIGNAL(topLevelChanged(bool)),        this, SLOT(previewFloated(bool)));
 }
