@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2020 Kevin B. Hendricks  Stratford, ON Canada
+**  Copyright (C) 2015-2022 Kevin B. Hendricks  Stratford, ON Canada
 **  Copyright (C) 2013      John Schember <john@nachtimwald.com>
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
@@ -45,18 +45,25 @@
 #include "ResourceObjects/ImageResource.h"
 #include "ResourceObjects/NCXResource.h"
 #include "ResourceObjects/OPFResource.h"
-#include "ResourceObjects/OPFParser.h"
 #include "ResourceObjects/NavProcessor.h"
 #include "sigil_constants.h"
 #include "sigil_exception.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
+#else
+    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
+#endif
+
 static const QString SIGIL_VERSION_META_NAME  = "Sigil version";
 static const QString OPF_XML_NAMESPACE        = "http://www.idpf.org/2007/opf";
 static const QString FALLBACK_MIMETYPE        = "text/plain";
 static const QString ITEM_ELEMENT_TEMPLATE    = "<item id=\"%1\" href=\"%2\" media-type=\"%3\"/>";
 static const QString ITEMREF_ELEMENT_TEMPLATE = "<itemref idref=\"%1\"/>";
 static const QString OPF_REWRITTEN_COMMENT    = "<!-- Your OPF file was broken so Sigil "
-        "tried to rebuild it for you. -->";
+                                                "tried to rebuild it for you. -->";
 
 static const QString PKG_VERSION = "<\\s*package[^>]*version\\s*=\\s*[\"\']([^\'\"]*)[\'\"][^>]*>";
 
@@ -69,9 +76,8 @@ static const QString TEMPLATE_TEXT =
     "    <dc:title>%3</dc:title>\n"
     "  </metadata>\n\n"
     "  <manifest>\n"
-    "    <item id=\"ncx\" href=\"toc.ncx\" media-type=\"application/x-dtbncx+xml\"/>\n"
     "  </manifest>\n\n"
-    "  <spine toc=\"ncx\">\n"
+    "  <spine>\n"
     "  </spine>\n\n"
     "</package>";
 
@@ -122,9 +128,9 @@ static const QString TEMPLATE3_TEXT =
 
 
 OPFResource::OPFResource(const QString &mainfolder, 
-			 const QString &fullfilepath, 
-			 const QString &version, 
-			 QObject *parent)
+             const QString &fullfilepath, 
+             const QString &version, 
+             QObject *parent)
   : XMLResource(mainfolder, fullfilepath, parent),
     m_NavResource(NULL),
     m_WarnedAboutVersion(false)
@@ -187,9 +193,9 @@ bool OPFResource::LoadFromDisk()
 {
     try {
         const QString &text = Utility::ReadUnicodeTextFile(GetFullPath());
-	SetText(text);
+        SetText(text);
         emit LoadedFromDisk();
-	return true;
+        return true;
     } catch (CannotOpenFile&) {
         //
     }
@@ -207,8 +213,8 @@ QList<Resource*> OPFResource::GetSpineOrderResources( const QList<Resource *> &r
     for (int i = 0; i < p.m_spine.count(); ++i) {
         QString idref = p.m_spine.at(i).m_idref;
         if (id_mapping.contains(idref)) {
-	    spine_order << id_mapping[idref];
-	}
+            spine_order << id_mapping[idref];
+        }
     }
     return spine_order;
 }
@@ -222,7 +228,7 @@ QHash <Resource *, int>  OPFResource::GetReadingOrderAll( const QList <Resource
     QHash <Resource *, int> reading_order;
     QHash<QString, int> id_order;
     for (int i = 0; i < p.m_spine.count(); ++i) {
-      id_order[p.m_spine.at(i).m_idref] = i;
+        id_order[p.m_spine.at(i).m_idref] = i;
     }
     QHash<Resource *, QString> id_mapping = GetResourceManifestIDMapping(resources, p);
     foreach(Resource *resource, resources) {
@@ -249,6 +255,41 @@ int OPFResource::GetReadingOrder(const HTMLResource *html_resource) const
     return -1;
 }
 
+void OPFResource::MoveReadingOrder(const HTMLResource* from_resource, const HTMLResource* after_resource)
+{
+    QWriteLocker locker(&GetLock());
+    const Resource *from_res = static_cast<const Resource *>(from_resource);
+    const Resource *after_res = static_cast<const Resource *>(after_resource);
+    if (from_res == NULL || after_res == NULL) return;
+
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
+    QString from_id = GetResourceManifestID(from_res, p);
+    QString after_id = GetResourceManifestID(after_res, p);
+
+    int from_pos = -1;
+    int after_pos = -1;
+    int spine_count = p.m_spine.count();
+    for (int i = 0; i < spine_count; i++) {
+        QString aref = p.m_spine.at(i).m_idref;
+        if (aref == from_id) from_pos = i;
+        if (aref == after_id) after_pos = i;
+    }
+
+    if ((from_pos < 0) || (after_pos < 0)) return;
+    if (from_pos >= spine_count || after_pos >= spine_count) return;
+    // a move is equivalent to the sequence insert(after, takeAt(from))
+    // if takeAt pos <  after pos, it effectively increases the after position by one
+    // if takeAt pos > after pos, you need to increment after pos by 1
+    if (from_pos != after_pos + 1) {
+        if (from_pos > after_pos) after_pos += 1;
+        p.m_spine.move(from_pos, after_pos);
+    }
+    UpdateText(p);
+}
+
+
 QString OPFResource::GetMainIdentifierValue() const
 {
     QReadLocker locker(&GetLock());
@@ -337,7 +378,7 @@ void OPFResource::EnsureUUIDIdentifierPresent()
     QString uuid = Utility::CreateUUID();
     // add in the proper identifier type prefix
     if (!uuid.startsWith("urn:uuid:")) {
-	uuid = "urn:uuid:" + uuid;
+        uuid = "urn:uuid:" + uuid;
     }
     WriteIdentifier("UUID", uuid, p);
     UpdateText(p);
@@ -401,7 +442,7 @@ void OPFResource::UpdateNCXLocationInManifest(const NCXResource *ncx)
     if (pos > -1) {
         ManifestEntry me = p.m_manifest.at(pos);
         QString href = me.m_href;
-	QString new_href = Utility::URLEncodePath(GetRelativePathToResource(ncx));
+        QString new_href = Utility::URLEncodePath(GetRelativePathToResource(ncx));
         me.m_href = new_href;
         p.m_manifest.replace(pos, me);
         p.m_hrefpos.remove(href);
@@ -473,8 +514,31 @@ bool OPFResource::CoverImageExists() const
 void OPFResource::AutoFixWellFormedErrors()
 {
     QWriteLocker locker(&GetLock());
+    const QStringList TEXT_EXTS = QStringList() << "htm" << "html" << "xhtml";
     QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
-    SetText(source);
+    OPFParser p;
+    p.parse(source);
+    // auto fill in spine from manifest if completely empty
+    if (p.m_spine.count() == 0) {
+        std::vector< std::pair< QString, QString > > txts;
+        for (int i=0; i < p.m_manifest.count(); i++) {
+            ManifestEntry me = p.m_manifest.at(i);
+            QString ahref = Utility::URLDecodePath(me.m_href);
+            QString aid = me.m_id;
+            QString ext = QFileInfo(ahref).suffix();
+            if ((me.m_mtype == "application/xhtml+xml") || TEXT_EXTS.contains(ext.toLower())) {
+                txts.push_back(std::make_pair(ahref, aid));
+            }
+        }
+        std::sort(txts.begin(), txts.end(), Utility::sort_string_pairs_by_first);
+        for (int j=0; j < txts.size(); j++) {
+            QString idref = txts.at(j).second;
+            SpineEntry sp;
+            sp.m_idref = idref;
+            p.m_spine << sp;
+        }
+    }
+    UpdateText(p);
 }
 
 
@@ -502,7 +566,7 @@ QString OPFResource::GetPrimaryBookTitle() const
     QString title = "";
     QStringList titles = GetDCMetadataValues("dc:title");
     if (!titles.isEmpty()) {
-	title = titles.at(0);
+        title = titles.at(0);
     }
     return title;
 }
@@ -576,15 +640,6 @@ void OPFResource::AddResource(const Resource *resource)
     me.m_mtype = GetResourceMimetype(resource);
     // Argh! If this is an new blank resource - it will have no content yet
     // so trying to parse it here to check for manifest properties is a mistake
-    // if (resource->Type() == Resource::HTMLResourceType) {
-    //     if (p.m_package.m_version == "3.0") {
-    //         const HTMLResource * html_resource = qobject_cast<const HTMLResource *>(resource);
-    //         QStringList properties = html_resource->GetManifestProperties();
-    //         if (properties.count() > 0) {
-    //             me.m_atts["properties"] = properties.join(QString(" "));
-    //         }
-    //     }
-    // }
     int n = p.m_manifest.count();
     p.m_manifest.append(me);
     p.m_idpos[me.m_id] = n;
@@ -671,6 +726,57 @@ void OPFResource::AddCoverMetaForImage(const Resource *resource, OPFParser &p)
     }
 }
 
+
+void OPFResource::BulkRemoveResources(const QList<Resource *>resources)
+{
+    QWriteLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
+    if (p.m_manifest.isEmpty()) return;
+
+    foreach(Resource * resource, resources) {
+        QString href = Utility::URLEncodePath(GetRelativePathToResource(resource));
+        int pos = p.m_hrefpos.value(href, -1);
+        QString item_id = "";
+
+        // Delete the meta tag for cover images before deleting the manifest entry
+        if (resource->Type() == Resource::ImageResourceType) {
+            RemoveCoverMetaForImage(resource, p);
+        }
+        if (pos > -1) {
+            item_id = p.m_manifest.at(pos).m_id;
+        }
+        if (resource->Type() == Resource::HTMLResourceType) {
+            for (int i=0; i < p.m_spine.count(); ++i) {
+                QString idref = p.m_spine.at(i).m_idref;
+                if (idref == item_id) {
+                    p.m_spine.removeAt(i);
+                    break;
+                }
+            }
+            RemoveGuideReferenceForResource(resource, p);
+            QString version = GetEpubVersion();
+            if (version.startsWith('3')) {
+                NavProcessor navproc(GetNavResource());
+                navproc.RemoveLandmarkForResource(resource);
+            }
+        }
+        if (pos > -1) {
+            p.m_manifest.removeAt(pos);
+            // rebuild the maps since updating them item by item would be slower
+            p.m_idpos.clear();
+            p.m_hrefpos.clear();
+            for (int i=0; i < p.m_manifest.count(); ++i) {
+                p.m_idpos[p.m_manifest.at(i).m_id] = i;
+                p.m_hrefpos[p.m_manifest.at(i).m_href] = i;
+            }
+        }
+    }
+    UpdateText(p);
+}
+
+
 void OPFResource::RemoveResource(const Resource *resource)
 {
     QWriteLocker locker(&GetLock());
@@ -769,7 +875,7 @@ int OPFResource::GetGuideReferenceForResourcePos(const Resource *resource, const
     for (int i=0; i < p.m_guide.count(); ++i) {
         GuideEntry ge = p.m_guide.at(i);
         QString href = ge.m_href;
-        QStringList parts = href.split('#', QString::KeepEmptyParts);
+        QStringList parts = href.split('#', QT_ENUM_KEEPEMPTYPARTS);
         if (parts.at(0) == href_to_resource_from_opf) {
             return i;
         }
@@ -802,14 +908,81 @@ void OPFResource::RemoveDuplicateGuideCodes(QString code, OPFParser& p)
 
 void OPFResource::RemoveGuideReferenceForResource(const Resource *resource, OPFParser& p)
 {
+    // if guide hrefs use fragments, the same resource may be there in multiple
+    // guide entries.  Since resource being deleted, remove them all
     if (p.m_guide.isEmpty()) return;
     int pos = GetGuideReferenceForResourcePos(resource, p);
-    if (pos > -1) {
+    while((pos > -1) && (!p.m_guide.isEmpty())) {
         p.m_guide.removeAt(pos);
+        pos = GetGuideReferenceForResourcePos(resource, p);
     }
 }
 
 
+void OPFResource::UpdateGuideFragments(QHash<QString,QString> &idupdates)
+{
+    QWriteLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
+    for(int c=0; c < p.m_guide.size(); c++) {
+        GuideEntry ge = p.m_guide.at(c);
+        QString href = ge.m_href;
+        std::pair<QString, QString> parts = Utility::parseRelativeHREF(href);
+        QString apath = Utility::URLDecodePath(parts.first);
+        QString bkpath = Utility::buildBookPath(apath, GetFolder());
+        QString key = bkpath + parts.second;
+        QString newid = idupdates.value(key,"");
+        if (!newid.isEmpty()) {
+            // found a fragment id needing to be updated
+            parts.second = "#" + newid;
+            href = Utility::buildRelativeHREF(apath, parts.second);
+            ge.m_href = href;
+            p.m_guide[c] = ge;
+        }
+    }
+    UpdateText(p);
+}
+
+
+// first merged resource in list is the sink resource
+void OPFResource::UpdateGuideAfterMerge(QList<Resource*> &merged_resources, QHash<QString,QString> &section_id_map)
+{
+    if (merged_resources.isEmpty() || merged_resources.size() < 2) return;
+    Resource* sink_resource = merged_resources.at(0);
+    QString sink_bookpath = sink_resource->GetRelativePath();
+    QStringList merged_bookpaths;
+    for (int i=1; i < merged_resources.size(); i++) {
+        Resource* res = merged_resources.at(i);
+        merged_bookpaths << res->GetRelativePath();
+    }
+    QWriteLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
+    for(int c=0; c < p.m_guide.size(); c++) {
+        GuideEntry ge = p.m_guide.at(c);
+        QString href = ge.m_href;
+        std::pair<QString, QString> parts = Utility::parseRelativeHREF(href);
+        QString apath = Utility::URLDecodePath(parts.first);
+        QString bkpath = Utility::buildBookPath(apath, GetFolder());
+        if (merged_bookpaths.contains(bkpath)) {
+            // need to redirect this bookpath to destination bookpath
+            // handle nay redirect to new injected section fragments
+            if (parts.second.isEmpty()) {
+                if (section_id_map.contains(bkpath)) {
+                    parts.second = "#" + section_id_map[bkpath];
+                }
+            }
+            apath = Utility::buildRelativePath(GetRelativePath(), sink_bookpath);
+            href = Utility::buildRelativeHREF(apath, parts.second);
+            ge.m_href = href;
+            p.m_guide[c] = ge;
+        }
+    }
+    UpdateText(p);
+}
+
 void OPFResource::SetGuideSemanticCodeForResource(QString code, const Resource *resource, OPFParser& p, const QString &lang)
 {
     if (code.isEmpty()) return;
@@ -848,21 +1021,21 @@ QString OPFResource::GetGuideSemanticNameForResource(Resource *resource)
 
 QHash <QString, QString>  OPFResource::GetSemanticCodeForPaths()
 {
-  QReadLocker locker(&GetLock());
-  QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
-  OPFParser p;
-  p.parse(source);
+    QReadLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
 
-  QHash <QString, QString> semantic_types;
-  foreach(GuideEntry ge, p.m_guide) {
-    QString href = ge.m_href;
-    QStringList parts = href.split('#', QString::KeepEmptyParts);
-    QString apath = Utility::URLDecodePath(parts.at(0));
-    QString bkpath = Utility::buildBookPath(apath, GetFolder());
-    QString gtype = ge.m_type;
-    semantic_types[bkpath] = gtype;
-  }
-  return semantic_types;
+    QHash <QString, QString> semantic_types;
+    foreach(GuideEntry ge, p.m_guide) {
+        QString href = ge.m_href;
+        QStringList parts = href.split('#', QT_ENUM_KEEPEMPTYPARTS);
+        QString apath = Utility::URLDecodePath(parts.at(0));
+        QString bkpath = Utility::buildBookPath(apath, GetFolder());
+        QString gtype = ge.m_type;
+        semantic_types[bkpath] = gtype;
+    }
+    return semantic_types;
 }
 
 
@@ -876,10 +1049,10 @@ QHash <QString, QString>  OPFResource::GetGuideSemanticNameForPaths()
     QHash <QString, QString> semantic_types;
     foreach(GuideEntry ge, p.m_guide) {
         QString href = ge.m_href;
-        QStringList parts = href.split('#', QString::KeepEmptyParts);
+        QStringList parts = href.split('#', QT_ENUM_KEEPEMPTYPARTS);
         QString gtype = ge.m_type;
         QString apath = Utility::URLDecodePath(parts.at(0));
-	QString bkpath = Utility::buildBookPath(apath, GetFolder());
+        QString bkpath = Utility::buildBookPath(apath, GetFolder());
         semantic_types[bkpath] = GuideItems::instance()->GetName(gtype);
     }
 
@@ -890,7 +1063,7 @@ QHash <QString, QString>  OPFResource::GetGuideSemanticNameForPaths()
         QString cover_id = me.m_atts.value(QString("content"),QString(""));
         ManifestEntry man = p.m_manifest.at(p.m_idpos[cover_id]);
         QString apath = Utility::URLDecodePath(man.m_href);
-	QString bkpath = Utility::buildBookPath(apath, GetFolder());
+        QString bkpath = Utility::buildBookPath(apath, GetFolder());
         semantic_types[bkpath] = GuideItems::instance()->GetName("cover");
     }
     return semantic_types;
@@ -1006,9 +1179,9 @@ void OPFResource::ResourceRenamed(const Resource *resource, QString old_full_pat
     if (resource->Type() == Resource::NCXResourceType) {
         // handle updating the ncx id on the spine if ncx renamed
         QString ncx_id = p.m_spineattr.m_atts.value(QString("toc"),"");
-	if (new_id != ncx_id) {
-	    p.m_spineattr.m_atts[QString("toc")] = new_id;
-	}
+        if (new_id != ncx_id) {
+            p.m_spineattr.m_atts[QString("toc")] = new_id;
+        }
     }
     if (resource->Type() == Resource::ImageResourceType) {
         // Change meta entry for cover if necessary
@@ -1082,14 +1255,14 @@ int OPFResource::GetMainIdentifier(const OPFParser& p) const
 }
 
 QHash<QString, Resource*>OPFResource::GetManifestIDResourceMapping(const QList<Resource *> &resources,
-						       const OPFParser &p)
+                               const OPFParser &p)
 {
     QHash<QString, Resource*> id_mapping;
     foreach(Resource * resource, resources) {
         QString href_path = Utility::URLEncodePath(GetRelativePathToResource(resource));
         int pos = p.m_hrefpos.value(href_path,-1);
         if (pos > -1) { 
-	    id_mapping[ p.m_manifest.at(pos).m_id ] = resource;
+            id_mapping[ p.m_manifest.at(pos).m_id ] = resource;
         }
     }
     return id_mapping;
@@ -1165,8 +1338,8 @@ void OPFResource::WriteIdentifier(const QString &metaname, const QString &metava
     if (pos > -1) {
         MetaEntry me = p.m_metadata.at(pos);
         QString scheme = me.m_atts.value(QString("scheme"),QString(""));
-	// epub3 no longer uses the scheme attribute
-	if (scheme.isEmpty() && me.m_content.startsWith("urn:uuid:")) scheme="UUID";
+    // epub3 no longer uses the scheme attribute
+    if (scheme.isEmpty() && me.m_content.startsWith("urn:uuid:")) scheme="UUID";
         if ((metavalue == me.m_content) && (metaname == scheme)) {
             return;
         }
@@ -1176,7 +1349,7 @@ void OPFResource::WriteIdentifier(const QString &metaname, const QString &metava
     me.m_name = QString("dc:identifier");
     // under the latest epub3 spec "scheme" is no longer an allowed attribute of dc:identifier
     if (epubversion.startsWith('2')) {
-	me.m_atts[QString("opf:scheme")] = metaname;
+        me.m_atts[QString("opf:scheme")] = metaname;
     }
     if (metaname.toLower() == "uuid" && !metavalue.contains("urn:uuid:")) {
         me.m_content = QString("urn:uuid:")  + metavalue;
@@ -1262,7 +1435,7 @@ QString OPFResource::GetOPFDefaultText(const QString &version)
     SettingsStore ss;
     QString defaultLanguage = ss.defaultMetadataLang();
     if (version.startsWith('2')) {
-      return TEMPLATE_TEXT.arg(Utility::CreateUUID()).arg(defaultLanguage).arg(tr("[Title here]"));
+        return TEMPLATE_TEXT.arg(Utility::CreateUUID()).arg(defaultLanguage).arg(tr("[Title here]"));
     }
     // epub 3 set dcterms:modified date time in ISO 8601 format
     QDateTime local(QDateTime::currentDateTime());
@@ -1419,7 +1592,7 @@ QHash <QString, QString>  OPFResource::GetManifestPropertiesForPaths()
         QString apath = Utility::URLDecodePath(me.m_href);
         if (me.m_atts.contains("properties")){
             QString properties = me.m_atts["properties"];
-	    apath = Utility::buildBookPath(apath, GetFolder());
+            apath = Utility::buildBookPath(apath, GetFolder());
             manifest_properties_all[apath] = properties;
         }
     }
