@@ -16,21 +16,6 @@ documentation:
 http://www.crummy.com/software/BeautifulSoup/bs4/doc/
 """
 
-from __future__ import unicode_literals, division, absolute_import, print_function
-
-import sys
-PY3 = sys.version_info[0] >= 3
-if PY3:
-    text_type = str
-    binary_type = bytes
-    basestring = str
-    unicode = str
-else:
-    range = xrange
-    text_type = unicode
-    binary_type = str
-
-
 __author__ = "Leonard Richardson (leonardr@segfault.org)"
 __version__ = "4.4.0"
 __copyright__ = "Copyright (c) 2004-2015 Leonard Richardson"
@@ -38,6 +23,7 @@ __license__ = "MIT"
 
 __all__ = ['BeautifulSoup']
 
+import sys
 import os
 import re
 import warnings
@@ -154,7 +140,7 @@ class BeautifulSoup(Tag):
 
         from_encoding = from_encoding or deprecated_argument(
             "fromEncoding", "from_encoding")
-        if from_encoding and isinstance(markup, unicode):
+        if from_encoding and isinstance(markup, str):
             warnings.warn("You provided Unicode markup but also provided a value for from_encoding. Your from_encoding will be ignored.")
             from_encoding = None
 
@@ -165,7 +151,7 @@ class BeautifulSoup(Tag):
 
         if builder is None:
             original_features = features
-            if isinstance(features, basestring):
+            if isinstance(features, str):
                 features = [features]
             if features is None or len(features) == 0:
                 features = self.DEFAULT_BUILDER_FEATURES
@@ -196,13 +182,13 @@ class BeautifulSoup(Tag):
             markup = markup.read()
         elif len(markup) <= 256 and (
                 (isinstance(markup, bytes) and not b'<' in markup)
-                or (isinstance(markup, unicode) and not u'<' in markup)
+                or (isinstance(markup, str) and not u'<' in markup)
         ):
             # Print out warnings for a couple beginner problems
             # involving passing non-markup to Beautiful Soup.
             # Beautiful Soup will still parse the input as markup,
             # just in case that's what the user really wants.
-            if (isinstance(markup, unicode)
+            if (isinstance(markup, str)
                 and not os.path.supports_unicode_filenames):
                 possible_filename = markup.encode("utf8")
             else:
@@ -216,16 +202,16 @@ class BeautifulSoup(Tag):
                 # system. Just let it go.
                 pass
             if is_file:
-                if isinstance(markup, unicode):
+                if isinstance(markup, str):
                     markup = markup.encode("utf8")
                 warnings.warn(
                     '"%s" looks like a filename, not markup. You should probably open this file and pass the filehandle into Beautiful Soup.' % markup)
             if markup[:5] == "http:" or markup[:6] == "https:":
                 # TODO: This is ugly but I couldn't get it to work in
                 # Python 3 otherwise.
-                if ((isinstance(markup, binary_type) and not b' ' in markup)
-                    or (isinstance(markup, unicode) and not ' ' in markup)):
-                    if isinstance(markup, unicode):
+                if ((isinstance(markup, bytes) and not b' ' in markup)
+                    or (isinstance(markup, str) and not ' ' in markup)):
+                    if isinstance(markup, str):
                         markup = markup.encode("utf8")
                     warnings.warn(
                         '"%s" looks like a URL. Beautiful Soup is not an HTTP client. You should probably use an HTTP client to get the document behind the URL, and feed that document to Beautiful Soup.' % markup)
