@@ -11,7 +11,7 @@ app_dir = os.path.dirname(os.path.realpath(__file__))
 app_dir = os.path.join(app_dir, 'Sigil.app','Contents','Frameworks')
 
 # actual version of Python used to build Sigil
-build_fwk = os.path.abspath(sys.prefix + '../../../')
+build_fwk = os.path.abspath(sys.prefix)
 
 # get python version string
 pversion = build_fwk.split(os.sep)[-1]
@@ -25,7 +25,7 @@ print('pversion', pversion)
 print('stdlib_dir', stdlib_dir)
 print('stdlib_name', stdlib_name)
 print('app_dir', app_dir)
-
+print('sys.prefix', os.path.abspath(sys.prefix))
 
 # the main Python.framework directories
 fwk_struct = ['Python.framework/Versions/' + pversion + '/lib/' + stdlib_name + '/site-packages',
@@ -66,6 +66,18 @@ site_packages = [ ('lxml', 'd'),
 #  ('test_regex.py', 'f'),
 
 
+def copy_python_tcltk(src_dir, dest_dir):
+    for x in os.listdir(src_dir):
+        y = os.path.join(src_dir, x)
+        ext = os.path.splitext(x)[1]
+        if os.path.isdir(y) and x not in ('python' + pversion, 'tcl8', 'pkgconfig', 'demos', 'tzdata'):
+            shutil.copytree(y, os.path.join(dest_dir, x),
+                    ignore=ignore_in_tcltk_dirs)
+        if os.path.isfile(y) and ext not in ('.sh', '.chm', '.htm', '.txt'):
+            if x != 'libpython' + pversion + '.dylib': 
+                shutil.copy2(y, dest_dir)
+
+                
 def copy_python_stdlibrary(src_dir, dest_dir):
     for x in os.listdir(src_dir):
         y = os.path.join(src_dir, x)
@@ -104,6 +116,23 @@ def copy_site_packages(packages, site_dest):
                 break
 
 
+def ignore_in_tcltk_dirs(base, items, ignored_dirs=None):
+    ans = []
+    dylibname = 'libpython' + pversion + '.dylib'
+    if ignored_dirs is None:
+        ignored_dirs = {'tcl8', 'python' + pversion, 'pkgconfig', 'demos', 'tzdata'}
+    for name in items:
+        path = os.path.join(base, name)
+        if os.path.isdir(path):
+            if name in ignored_dirs:
+                ans.append(name)
+        else:
+            if name.rpartition('.')[-1] in ('chm', 'htm', 'html', 'txt' ):
+                ans.append(name)
+            if name == dylibname:
+                ans.append(name)
+    return ans
+
 def ignore_in_dirs(base, items, ignored_dirs=None):
     ans = []
     if ignored_dirs is None:
@@ -176,6 +205,8 @@ def main():
     dest_dir = os.path.join(app_dir,'Python.framework','Versions', pversion, 'lib', stdlib_name, 'site-packages')
     copy_site_packages(site_packages, dest_dir)
 
+    dest_dir = os.path.join(app_dir,'Python.framework','Versions', pversion, 'lib')
+    
     # now pre-compile all of the .py code and replace it by .pyc
     dest_dir = os.path.join(app_dir,'Python.framework','Versions', pversion, 'lib', stdlib_name)
     for x in os.walk(dest_dir):
@@ -190,8 +221,14 @@ def main():
                     # if os.path.exists(z):
                     #     os.remove(z)
                 except:
+
                     print ('Failed to byte-compile', y)
 
+    # copy the embedded tcl/tk fpieces
+    tcltksrcdir = os.path.join(build_fwk, 'lib')
+    tcltkdestdir = os.path.join(app_dir,  'Python.framework', 'Versions', pversion, 'lib')
+    copy_python_tcltk(tcltksrcdir, tcltkdestdir)
+    
     # next copy the bin
     src_file = os.path.join(build_fwk, 'bin', 'python3')
     dest_file = os.path.join(app_dir,  'Python.framework', 'Versions', pversion, 'bin', 'python3')
@@ -218,7 +255,6 @@ def main():
     os.symlink(os.path.join('Versions', 'Current', 'Resources'), 'Resources')
 
     os.chdir(os.path.join(app_dir, 'Python.framework', 'Versions', pversion, 'lib'))
-    # dylibname = 'libpython' + pversion + 'm.dylib'
     dylibname = 'libpython' + pversion + '.dylib'
     os.symlink('../Python', dylibname)
 
