@@ -575,6 +575,8 @@ private slots:
 
     void GoToLinkOrStyleAction();
 
+    void ToggleLineWrapMode();
+
     void ReformatCSSMultiLineAction();
     void ReformatCSSSingleLineAction();
 
@@ -648,6 +650,8 @@ private:
 
     void AddGoToLinkOrStyleContextMenu(QMenu *menu);
 
+    void AddToggleLineWrapModeContextMenu(QMenu *menu);
+
     void AddClipContextMenu(QMenu *menu);
 
     void AddMarkSelectionMenu(QMenu *menu);
