@@ -1,7 +1,7 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford Ontario Canada
-**  Copyright (C) 2015-2021 Doug Massay
+**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2015-2022 Doug Massay
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -25,17 +25,6 @@
 #include <QStringList>
 #include "sigil_constants.h"
 
-const QString CLIPS_SETTINGS_FILE = "sigil_clips.ini";
-const QString INDEX_SETTINGS_FILE = "sigil_index.ini";
-const QString SEARCHES_SETTINGS_FILE = "sigil_searches.ini";
-const QString SEARCHES_V2_SETTINGS_FILE = "sigil_searches_v2.ini";
-const QString SIGIL_SETTINGS_FILE = "sigil.ini";
-
-const QString CLIPS_V6_SETTINGS_FILE = "sigil_clips_v6.ini";
-const QString INDEX_V6_SETTINGS_FILE = "sigil_index_v6.ini";
-const QString SEARCHES_V6_SETTINGS_FILE = "sigil_searches_v6.ini";
-const QString SIGIL_V6_SETTINGS_FILE = "sigil_v6.ini";
-
 #if _WIN32
 #include <QProcessEnvironment>
 
@@ -74,7 +63,7 @@ const QString force_sigil_darkmode_palette = QString(getenv("FORCE_SIGIL_DARKMOD
 const QString sigil_share_root = QString(SIGIL_SHARE_ROOT);
 const bool dicts_are_bundled = DICTS_ARE_BUNDLED;
 const QString extra_dict_dirs = QString(EXTRA_DICT_DIRS);
-const QString mathjax_dir = QString(MATHJAX_DIR);
+const QString mathjax3_dir = QString(MATHJAX3_DIR);
 const QString PYTHON_MAIN_PATH = "/python3/lib/python3.5";
 #if __x86_64__ || __ppc64__
 const QStringList PYTHON_SYS_PATHS = QStringList () << "/plat-x86_64-linux-gnu" << "/plat-linux" << "/lib-dynload" << "/site-packages";
